@@ -1,9 +1,13 @@
 import logging
 from abc import ABC, abstractmethod
-from pathlib import PosixPath
 from typing import Iterable, Tuple
 
-from tempren.path_generator import File
+from tempren.path_generator import (
+    ExpressionEvaluationError,
+    File,
+    TemplateEvaluationError,
+    evaluate_expression,
+)
 from tempren.template.tree_elements import Pattern
 
 
@@ -17,10 +21,10 @@ class TemplateFileSorter(FileSorter):
     log: logging.Logger
     pattern: Pattern
     invert: bool = False
-    _evaluation_locals = {"PosixPath": PosixPath}
 
     def __init__(self, pattern: Pattern, invert: bool = False):
         self.log = logging.getLogger(__name__)
+
         self.pattern = pattern
         self.invert = invert
 
@@ -31,6 +35,15 @@ class TemplateFileSorter(FileSorter):
         self.log.debug("Rendering sorting value template for '%s'", file)
         rendered_expression = "(" + self.pattern.process_as_expression(file) + ", )"
         self.log.debug("Evaluating sorting value expression '%s'", rendered_expression)
-        evaluation_result = eval(rendered_expression, {}, self._evaluation_locals)
-        self.log.debug("Evaluation result '%s'", repr(evaluation_result))
-        return evaluation_result
+        try:
+            evaluation_result = evaluate_expression(rendered_expression)
+            self.log.debug("Evaluation result '%s'", repr(evaluation_result))
+            return evaluation_result
+        except ExpressionEvaluationError as evaluation_error:
+            assert self.pattern.source_representation is not None
+            raise TemplateEvaluationError(
+                file,
+                self.pattern.source_representation,
+                evaluation_error.expression,
+                evaluation_error.message,
+            )
